@@ -8,4 +8,4 @@ class PaymentProcessor(PaymentProcessorBase):
     BACKEND_ACCEPTED_CURRENCY = ('PLN', 'EUR', 'USD')
 
     def get_gateway_url(self, request):
-        return reverse('getpaid-dummy-authorization', kwargs={'pk' : self.payment.pk})
\ No newline at end of file
+        return reverse('getpaid-dummy-authorization', kwargs={'pk' : self.payment.pk}), "GET", {}
\ No newline at end of file
