@@ -4,6 +4,7 @@ import logging
 import urllib
 import datetime
 from django.contrib.sites.models import Site
+from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse
 from django.db.models.loading import get_model
 from django.utils.timezone import utc
@@ -26,6 +27,8 @@ class PaymentProcessor(PaymentProcessorBase):
     _ALLOWED_IP = ('195.149.229.109', )
 
     _ONLINE_SIG_FIELDS = ('id', 'tr_id', 'tr_amount', 'tr_crc', )
+    _ACCEPTED_LANGS = ('pl', 'en', 'de')
+
 
     @staticmethod
     def compute_sig(params, fields, key):
@@ -64,6 +67,9 @@ class PaymentProcessor(PaymentProcessorBase):
 
         logger.info('Incoming payment: id=%s, tr_id=%s, tr_date=%s, tr_crc=%s, tr_amount=%s, tr_paid=%s, tr_desc=%s, tr_status=%s, tr_error=%s, tr_email=%s' % (id, tr_id, tr_date, tr_crc, tr_amount, tr_paid, tr_desc, tr_status, tr_error, tr_email))
 
+        payment.external_id = tr_id
+        payment.description = tr_email
+
         if tr_status == 'TRUE':
             # Due to Transferuj documentation, we need to check if amount is correct
             payment.amount_paid = Decimal(tr_paid)
@@ -96,6 +102,14 @@ class PaymentProcessor(PaymentProcessorBase):
 
         signals.user_data_query.send(sender=None, order=self.payment.order, user_data=user_data)
 
+
+        if user_data['lang'] and user_data['lang'].lower() in PaymentProcessor._ACCEPTED_LANGS:
+            params['jezyk'] = user_data['lang'].lower()
+        elif PaymentProcessor.get_backend_setting('lang', False) and\
+             PaymentProcessor.get_backend_setting('lang').lower() in PaymentProcessor._ACCEPTED_LANGS:
+            params['jezyk'] = PaymentProcessor.get_backend_setting('lang').lower()
+
+
         if user_data['email']:
             params['email'] = user_data['email']
 
@@ -112,11 +126,6 @@ class PaymentProcessor(PaymentProcessorBase):
         if signing:
             params['md5sum'] = PaymentProcessor.compute_sig(params, self._REQUEST_SIG_FIELDS, key)
 
-        for key in params.keys():
-            params[key] = unicode(params[key]).encode('utf-8')
-
-        print type(params['opis']), params['opis']
-
         current_site = Site.objects.get_current()
 
         if PaymentProcessor.get_backend_setting('force_ssl_online', False):
@@ -131,6 +140,16 @@ class PaymentProcessor(PaymentProcessorBase):
             params['pow_url'] = 'http://' + current_site.domain + reverse('getpaid-transferuj-success', kwargs={'pk': self.payment.pk})
             params['pow_url_blad'] = 'http://' + current_site.domain + reverse('getpaid-transferuj-failure', kwargs={'pk': self.payment.pk})
 
-        gateway_url = self._GATEWAY_URL + '?' + urllib.urlencode(params)
-        return gateway_url
+
+        if PaymentProcessor.get_backend_setting('method', 'get').lower() == 'post':
+            return self._GATEWAY_URL , 'POST', params
+        elif PaymentProcessor.get_backend_setting('method', 'get').lower() == 'get':
+            for key in params.keys():
+                params[key] = unicode(params[key]).encode('utf-8')
+            return self._GATEWAY_URL + '?' + urllib.urlencode(params), "GET", {}
+        else:
+            raise ImproperlyConfigured('Transferuj.pl payment backend accepts only GET or POST')
+
+
+
 
